@@ -16,6 +16,7 @@
 import collections
 import copy
 import enum
+import json
 import sys
 from typing import List
 
@@ -41,6 +42,8 @@ _DEPENDENCY_GROUP = '/groups/dependencies'
 _REVERSE_CLOSURE = '/reverseClosure'
 _CONSUMER_SERVICE_RESOURCE = '%s/services/%s'
 _CONSUMER_POLICY_DEFAULT = '/consumerPolicies/%s'
+_MCP_POLICY_DEFAULT = '/mcpPolicies/%s'
+_CONTENT_SECURITY_POLICY_DEFAULT = '/contentSecurityPolicies/%s'
 _EFFECTIVE_POLICY = '/effectivePolicy'
 _GOOGLE_CATEGORY_RESOURCE = 'categories/google'
 _LIMIT_OVERRIDE_RESOURCE = '%s/consumerOverrides/%s'
@@ -103,35 +106,135 @@ def GetConsumerPolicyV2Beta(policy_name):
     exceptions.ReraiseError(e, exceptions.GetConsumerPolicyException)
 
 
-# TODO(b/393195807) Remove after the migration is completed.
-def GetConsumerPolicyV2Alpha(policy_name):
-  """Make API call to get a consumer policy.
+def GetMcpPolicy(policy_name):
+  """Make API call to get a MCP policy.
 
   Args:
-    policy_name: The name of a consumer policy. Currently supported format
-      '{resource_type}/{resource_name}/consumerPolicies/default'. For example,
-      'projects/100/consumerPolicies/default'.
+    policy_name: The name of a MCP policy. Currently supported format
+      '{resource_type}/{resource_name}/mcpPolicies/default'. For example,
+      'projects/100/mcpPolicies/default'.
 
   Raises:
-    exceptions.GetConsumerPolicyPermissionDeniedException: when getting a
-      consumer policy fails.
+    exceptions.GetMcpPolicyException: when getting a
+      MCP policy fails.
     apitools_exceptions.HttpError: Another miscellaneous error with the service.
 
   Returns:
-    The consumer policy
+    The MCP policy
   """
-  client = _GetClientInstance(_V2ALPHA_VERSION)
+  client = _GetClientInstance(_V2BETA_VERSION)
   messages = client.MESSAGES_MODULE
 
-  request = messages.ServiceusageConsumerPoliciesGetRequest(name=policy_name)
+  request = messages.ServiceusageMcpPoliciesGetRequest(name=policy_name)
 
   try:
-    return client.consumerPolicies.Get(request)
+    return client.mcpPolicies.Get(request)
   except (
       apitools_exceptions.HttpForbiddenError,
       apitools_exceptions.HttpNotFoundError,
   ) as e:
-    exceptions.ReraiseError(e, exceptions.GetConsumerPolicyException)
+    exceptions.ReraiseError(e, exceptions.GetMcpPolicyException)
+
+
+def GetContentSecurityPolicy(name):
+  """Make API call to get the content security policy for a given project, folder or organization.
+
+  Args:
+    name: The name of a content security policy. Currently supported format
+      '{resource_type}/{resource_name}/contentSecurityPolicies/default'. For
+      example, 'projects/100/contentSecurityPolicies/default'.
+
+  Raises:
+    exceptions.GetContentSecurityPolicyException: when getting a
+      content security policy fails.
+    apitools_exceptions.HttpError: Another miscellaneous error with the service.
+
+  Returns:
+    The content security policy.
+  """
+  client = _GetClientInstance(_V2BETA_VERSION)
+  messages = client.MESSAGES_MODULE
+
+  request = messages.ServiceusageContentSecurityPoliciesGetRequest(name=name)
+
+  try:
+    return client.contentSecurityPolicies.Get(request)
+  except (
+      apitools_exceptions.HttpForbiddenError,
+      apitools_exceptions.HttpNotFoundError,
+  ) as e:
+    exceptions.ReraiseError(e, exceptions.GetContentSecurityPolicyException)
+
+
+def UpdateContentSecurityPolicy(name, content_security_policy):
+  """Make API call to update the content security policy for a given project, folder or organization.
+
+  Args:
+    name: The name of a content security policy. Currently supported format
+      '{resource_type}/{resource_name}/contentSecurityPolicies/default'. For
+      example, 'projects/100/contentSecurityPolicies/default'.
+    content_security_policy: The content security policy to update.
+
+  Raises:
+    exceptions.UpdateContentSecurityPolicyException: when updating a
+      content security policy fails.
+    apitools_exceptions.HttpError: Another miscellaneous error with the service.
+
+  Returns:
+    The content security policy.
+  """
+  client = _GetClientInstance(_V2BETA_VERSION)
+  messages = client.MESSAGES_MODULE
+
+  request = messages.ServiceusageContentSecurityPoliciesPatchRequest(
+      name=name, contentSecurityPolicy=content_security_policy
+  )
+
+  try:
+    return client.contentSecurityPolicies.Patch(request)
+  except (
+      apitools_exceptions.HttpForbiddenError,
+      apitools_exceptions.HttpNotFoundError,
+  ) as e:
+    exceptions.ReraiseError(e, exceptions.UpdateContentSecurityPolicyException)
+
+
+def TestMcpEnabled(name: str, service: str):
+  """Make API call to test MCP enabled.
+
+  Args:
+    name: Parent resource to test a value against the result of merging MCP
+      policies in the resource hierarchy. Format: "projects/{PROJECT_ID}" (e.g.,
+      "projects/foo-bar"), "projects/{PROJECT_NUMBER}" (e.g.,
+      "projects/12345678"), "folders/{FOLDER_NUMBER}" (e.g., "folders/1234567")
+      , "organizations/{ORGANIZATION_NUMBER}" (e.g., "organizations/123456").
+    service: Service name to check if the targeted resource can use this service
+      for MCP. Current supported value: services/{SERVICE_NAME} (format:
+      "services/{service}").
+
+  Raises:
+    exceptions.TestMcpEnabledException: when testing value for a
+      service and resource.
+    apitools_exceptions.HttpError: Another miscellaneous error with the service.
+
+  Returns:
+    Message.State: The state of the service.
+  """
+  client = _GetClientInstance(_V2BETA_VERSION)
+  messages = client.MESSAGES_MODULE
+
+  request = messages.ServiceusageTestMcpEnabledRequest(
+      name=name,
+      testMcpEnabledRequest=messages.TestMcpEnabledRequest(serviceName=service),
+  )
+
+  try:
+    return client.v2beta.TestMcpEnabled(request)
+  except (
+      apitools_exceptions.HttpForbiddenError,
+      apitools_exceptions.HttpNotFoundError,
+  ) as e:
+    exceptions.ReraiseError(e, exceptions.TestMcpEnabledException)
 
 
 def TestEnabled(name: str, service: str):
@@ -179,7 +282,7 @@ def GetEffectivePolicyV2Beta(name: str, view: str = 'BASIC'):
     view: The view of the effective policy to use. The default view is 'BASIC'.
 
   Raises:
-    exceptions.GetEffectiverPolicyException: when getting a
+    exceptions.GetEffectivePolicyException: when getting a
       effective policy fails.
     apitools_exceptions.HttpError: Another miscellaneous error with the service.
 
@@ -207,51 +310,81 @@ def GetEffectivePolicyV2Beta(name: str, view: str = 'BASIC'):
       apitools_exceptions.HttpForbiddenError,
       apitools_exceptions.HttpNotFoundError,
   ) as e:
-    exceptions.ReraiseError(e, exceptions.GetEffectiverPolicyException)
+    exceptions.ReraiseError(e, exceptions.GetEffectivePolicyException)
 
 
-# TODO(b/393195807) Remove after the migration is completed.
-def GetEffectivePolicyV2Alpha(name: str, view: str = 'BASIC'):
-  """Make API call to get a effective policy.
+def GetEffectiveMcpPolicy(name: str, view: str = 'BASIC'):
+  """Make API call to get a effective MCP policy.
 
   Args:
-    name: The name of the effective policy. Currently supported format
-      '{resource_type}/{resource_name}/effectivePolicy'. For example,
+    name: The name of the effective MCP policy. Currently supported format
+      '{resource_type}/{resource_name}/effectiveMcpPolicy'. For example,
       'projects/100/effectivePolicy'.
-    view: The view of the effective policy to use. The default view is 'BASIC'.
+    view: The view of the effective MCP policy to use. The default view is
+      'BASIC'.
 
   Raises:
-    exceptions.GetEffectiverPolicyPermissionDeniedException: when getting a
+    exceptions.GetEffectiveMcpPolicyException: when getting a
       effective policy fails.
     apitools_exceptions.HttpError: Another miscellaneous error with the service.
 
   Returns:
-    The Effective Policy
+    message.EffectiveMcpPolicy: The effective MCP policy
   """
-  client = _GetClientInstance(_V2ALPHA_VERSION)
+  client = _GetClientInstance(version=_V2BETA_VERSION)
   messages = client.MESSAGES_MODULE
   if view == 'BASIC':
     view_type = (
-        messages.ServiceusageGetEffectivePolicyRequest.ViewValueValuesEnum.EFFECTIVE_POLICY_VIEW_BASIC
+        messages.ServiceusageGetEffectiveMcpPolicyRequest.ViewValueValuesEnum.EFFECTIVE_MCP_POLICY_VIEW_BASIC
     )
   else:
     view_type = (
-        messages.ServiceusageGetEffectivePolicyRequest.ViewValueValuesEnum.EFFECTIVE_POLICY_VIEW_FULL
+        messages.ServiceusageGetEffectiveMcpPolicyRequest.ViewValueValuesEnum.EFFECTIVE_MCP_POLICY_VIEW_FULL
     )
 
-  request = messages.ServiceusageGetEffectivePolicyRequest(
+  request = messages.ServiceusageGetEffectiveMcpPolicyRequest(
       name=name, view=view_type
   )
 
   try:
-    return client.v2alpha.GetEffectivePolicy(request)
+    return client.v2beta.GetEffectiveMcpPolicy(request)
   except (
       apitools_exceptions.HttpForbiddenError,
       apitools_exceptions.HttpNotFoundError,
   ) as e:
-    exceptions.ReraiseError(
-        e, exceptions.GetEffectiverPolicyPermissionDeniedException
-    )
+    exceptions.ReraiseError(e, exceptions.GetEffectiveMcpPolicyException)
+
+
+def GetServiceV2Beta(service):
+  """Make API call to get service state for a service .
+
+  Args:
+    service: Service. Current supported value:(format:
+      "{resource}/{resource_Id}/services/{service}").
+
+  Raises:
+    exceptions.GetServiceException: when getting service
+      service state for service in the resource.
+    apitools_exceptions.HttpError: Another miscellaneous error with the service.
+
+  Returns:
+    Message.GetServicesResponse: Service state of the given resource.
+  """
+  client = _GetClientInstance(version=_V2BETA_VERSION)
+  messages = client.MESSAGES_MODULE
+
+  request = messages.ServiceusageServicesGetRequest(
+      name=service,
+      view=messages.ServiceusageServicesGetRequest.ViewValueValuesEnum.SERVICE_STATE_VIEW_FULL,
+  )
+
+  try:
+    return client.services.Get(request)
+  except (
+      apitools_exceptions.HttpForbiddenError,
+      apitools_exceptions.HttpNotFoundError,
+  ) as e:
+    exceptions.ReraiseError(e, exceptions.GetServiceException)
 
 
 def BatchGetService(parent, services):
@@ -378,6 +511,43 @@ def UpdateConsumerPolicyV2Alpha(
     exceptions.ReraiseError(e, exceptions.Error)
 
 
+def UpdateMcpPolicy(policy, name, force=False, validateonly=False):
+  """Make API call to update a MCP policy.
+
+  Args:
+    policy: The MCP policy to update.
+    name: The resource name of the MCP policy. Currently supported format
+      '{resource_type}/{resource_name}/mcpPolicies/default. For example,
+      'projects/100/mcpPolicies/default'.
+    force: Disable service with usage within last 30 days or disable recently
+      enabled service.(not supported during MVP.)
+    validateonly: If set, validate the request and preview the result but do not
+      actually commit it. The default is false.(not supported during MVP.)
+
+  Raises:
+    exceptions.class UpdateMcpPolicyException: when getting a
+      MCP policy fails.
+    apitools_exceptions.HttpError: Another miscellaneous error with the service.
+
+  Returns:
+    The MCP policy
+  """
+  client = _GetClientInstance(_V2BETA_VERSION)
+  messages = client.MESSAGES_MODULE
+
+  request = messages.ServiceusageMcpPoliciesPatchRequest(
+      mcpPolicy=policy, name=name, force=force, validateOnly=validateonly
+  )
+
+  try:
+    return client.mcpPolicies.Patch(request)
+  except (
+      apitools_exceptions.HttpForbiddenError,
+      apitools_exceptions.HttpNotFoundError,
+  ) as e:
+    exceptions.ReraiseError(e, exceptions.UpdateMcpPolicyException)
+
+
 def UpdateConsumerPolicyV2Beta(
     consumerpolicy, name, force=False, validateonly=False
 ):
@@ -473,7 +643,10 @@ def ListGroupMembers(
       apitools_exceptions.HttpForbiddenError,
       apitools_exceptions.HttpNotFoundError,
   ) as e:
-    exceptions.ReraiseError(e, exceptions.ListGroupMembersException)
+    if 'SU_GROUP_NOT_FOUND' in str(e):
+      return []
+    else:
+      exceptions.ReraiseError(e, exceptions.ListGroupMembersException)
 
 
 def ListDescendantServices(
@@ -560,7 +733,10 @@ def ListExpandedMembers(resource: str, service_group: str, page_size: int = 50):
       apitools_exceptions.HttpForbiddenError,
       apitools_exceptions.HttpNotFoundError,
   ) as e:
-    exceptions.ReraiseError(e, exceptions.ListExpandedMembersException)
+    if 'SU_GROUP_NOT_FOUND' in str(e):
+      return []
+    else:
+      exceptions.ReraiseError(e, exceptions.ListExpandedMembersException)
 
 
 def ListAncestorGroups(resource: str, service: str, page_size: int = 50):
@@ -642,6 +818,215 @@ def AnalyzeConsumerPolicy(
     exceptions.ReraiseError(e, exceptions.AnalyzeConsumerPolicyException)
 
 
+def UpdateConsumerPolicy(
+    consumerpolicy,
+    validate_only: bool = False,
+    bypass_dependency_check: bool = False,
+    force: bool = False,
+):
+  """Make API call to update a consumer policy.
+
+  Args:
+    consumerpolicy: The consumer policy to update.
+    validate_only: If True, the action will be validated and result will be
+      preview but not exceuted.
+    bypass_dependency_check: If True, dependencies check will be bypassed.
+    force: If True, the system will bypass usage checks for services that are
+      being removed.
+
+  Raises:
+    exceptions.UpdateConsumerPolicyException: when updating policy API fails.
+    apitools_exceptions.HttpError: Another miscellaneous error with the service.
+
+  Returns:
+    The result of the operation
+  """
+
+  client = _GetClientInstance(version=_V2BETA_VERSION)
+  messages = client.MESSAGES_MODULE
+
+  try:
+
+    policy = messages.GoogleApiServiceusageV2betaConsumerPolicy(
+        name=consumerpolicy['name']
+    )
+
+    if (
+        'enableRules' in consumerpolicy.keys()
+        and consumerpolicy['enableRules'] is not None
+    ):
+      for enable_rule in consumerpolicy['enableRules']:
+        if 'services' in enable_rule:
+          policy.enableRules.append(
+              messages.GoogleApiServiceusageV2betaEnableRule(
+                  services=enable_rule['services']
+              )
+          )
+
+    if not bypass_dependency_check:
+      op = AnalyzeConsumerPolicy(policy)
+
+      op = services_util.WaitOperation(op.name, GetOperationV2Beta)
+
+      analysis_reponse = encoding.MessageToDict(op.response)
+
+      missing_dependencies = {}
+
+      if 'analysis' in analysis_reponse:
+        for analysis in analysis_reponse['analysis']:
+          for warning in analysis['analysisResult']['warnings']:
+            if analysis['service'] not in missing_dependencies.keys():
+              missing_dependencies[analysis['service']] = [
+                  warning['missingDependency']
+              ]
+            else:
+              missing_dependencies[analysis['service']].append(
+                  warning['missingDependency']
+              )
+
+      if missing_dependencies:
+        error_message = 'Policy cannot be updated as \n'
+        for service in missing_dependencies:
+          for dependency in missing_dependencies[service]:
+            error_message += (
+                service + ' is missing service dependency ' + dependency + '\n'
+            )
+
+        raise exceptions.ConfigError(error_message)
+
+    return UpdateConsumerPolicyV2Beta(
+        policy,
+        policy.name,
+        validateonly=validate_only,
+        force=force,
+    )
+  except (
+      apitools_exceptions.HttpForbiddenError,
+      apitools_exceptions.HttpNotFoundError,
+  ) as e:
+    exceptions.ReraiseError(e, exceptions.UpdateConsumerPolicyException)
+
+
+def AddContentSecurityProvider(
+    content_security_provider: str,
+    resource_name: str,
+):
+  """Make API call to add a content security provider.
+
+  Args:
+    content_security_provider: The content security provider to add.
+    resource_name: The resource name of the content security policy.
+
+  Raises:
+    exceptions.AddContentSecurityProviderException: when adding content security
+    provider to content security policy fails.
+    apitools_exceptions.HttpError: Another miscellaneous error with the service.
+
+  Returns:
+    The result of the operation
+  """
+
+  client = _GetClientInstance(version=_V2BETA_VERSION)
+  messages = client.MESSAGES_MODULE
+
+  try:
+    content_security_policy = GetContentSecurityPolicy(resource_name)
+
+    if not content_security_provider.startswith('services/'):
+      content_security_provider = f'services/{content_security_provider}'
+
+    mcp_content_security = content_security_policy.mcpContentSecurity
+
+    existing_content_security_providers = [
+        p.name for p in mcp_content_security.contentSecurityProviders
+    ]
+
+    if content_security_provider in existing_content_security_providers:
+      raise exceptions.ConfigError(
+          f'The content security provider {content_security_provider} already'
+          ' exists.'
+      )
+
+    update_policy = copy.deepcopy(content_security_policy)
+
+    update_policy.mcpContentSecurity.contentSecurityProviders.append(
+        messages.ContentSecurityProvider(name=content_security_provider)
+    )
+
+    return UpdateContentSecurityPolicy(
+        resource_name,
+        update_policy,
+    )
+
+  except (
+      apitools_exceptions.HttpForbiddenError,
+      apitools_exceptions.HttpNotFoundError,
+  ) as e:
+    exceptions.ReraiseError(e, exceptions.AddContentSecurityProviderException)
+
+
+def RemoveContentSecurityProvider(
+    content_security_provider: str,
+    resource_name: str,
+):
+  """Make API call to remove a content security provider.
+
+  Args:
+    content_security_provider: The content security provider to remove.
+    resource_name: The resource name of the content security policy.
+
+  Raises:
+    exceptions.RemoveContentSecurityProviderException: when removing content
+    security
+    provider from content security policy fails.
+    apitools_exceptions.HttpError: Another miscellaneous error with the service.
+
+  Returns:
+    The result of the operation
+  """
+
+  try:
+    content_security_policy = GetContentSecurityPolicy(resource_name)
+
+    if not content_security_provider.startswith('services/'):
+      content_security_provider = f'services/{content_security_provider}'
+
+    update_policy = copy.deepcopy(content_security_policy)
+    mcp_content_security = update_policy.mcpContentSecurity
+
+    updated_content_security_providers = []
+    is_present = False
+
+    for p in mcp_content_security.contentSecurityProviders:
+      if p.name == content_security_provider:
+        is_present = True
+      else:
+        updated_content_security_providers.append(p)
+
+    if not is_present:
+      raise exceptions.ConfigError(
+          f'The content security provider {content_security_provider} does not'
+          ' exist.'
+      )
+
+    mcp_content_security.contentSecurityProviders = (
+        updated_content_security_providers
+    )
+
+    return UpdateContentSecurityPolicy(
+        resource_name,
+        update_policy,
+    )
+
+  except (
+      apitools_exceptions.HttpForbiddenError,
+      apitools_exceptions.HttpNotFoundError,
+  ) as e:
+    exceptions.ReraiseError(
+        e, exceptions.RemoveContentSecurityProviderException
+    )
+
+
 def AddEnableRule(
     services: List[str],
     project: str,
@@ -690,42 +1075,59 @@ def AddEnableRule(
     policy = GetConsumerPolicyV2Beta(policy_name)
 
     services_to_enabled = set()
-
+    existing_services = set()
     if policy.enableRules:
-      enabled_services = set(policy.enableRules[0].services)
-      for service in services:
-        # Check if services to add is not already present in the policy.
-        if _SERVICE_RESOURCE % service not in enabled_services:
-          services_to_enabled.add(_SERVICE_RESOURCE % service)
-    else:
-      for service in services:
+      existing_services = set(policy.enableRules[0].services)
+
+    for service in services:
+      # Check if services to add is not already present in the policy.
+      if _SERVICE_RESOURCE % service not in existing_services:
         services_to_enabled.add(_SERVICE_RESOURCE % service)
 
-    if not services_to_enabled:
-      raise exceptions.ConfigError(
-          'The service(s) '
-          + ','.join(services)
-          + ' are already enabled and present in the consumer policy'
-      )
+    dependent_services = set()
 
     if not skip_dependency:
-      dependent_services = []
-      for service in services_to_enabled:
+      for service in services:
         list_expanded_members = ListExpandedMembers(
-            resource_name, service + _DEPENDENCY_GROUP
+            resource_name, _SERVICE_RESOURCE % service + _DEPENDENCY_GROUP
         )
         for dependent_service in list_expanded_members:
           # dependent_service is in format services/{service_name}
-          dependent_services.append(dependent_service)
+          dependent_service_name = dependent_service.split('/')[-1]
+          # Check if dependent services to add is not already present in the
+          # input services.
+          if dependent_service_name not in services:
+            dependent_services.add(dependent_service)
 
-      for service in dependent_services:
-        services_to_enabled.add(service)
+      for service in list(dependent_services):
+        # check if dependent services are already enabled
+        if service not in existing_services:
+          services_to_enabled.add(service)
+
+    if not services_to_enabled:
+      if skip_dependency:
+        raise exceptions.ConfigError(
+            'The service(s) '
+            + ','.join(services)
+            + ' are already enabled and present in the consumer policy'
+        )
+      else:
+        service_list_str = ','.join(services)
+        message = f'The service(s) {service_list_str}'
+
+        if dependent_services:
+          # if dependent services are present and not in services,
+          # add them to the error message.
+
+          dependent_list_str = ','.join(list(dependent_services))
+          message += f' and their dependencies {dependent_list_str}'
+
+        message += ' are already enabled and present in the consumer policy'
+        raise exceptions.ConfigError(message)
 
     if policy.enableRules:
       for service in list(services_to_enabled):
-        # check if dependent services are already enabled
-        if service not in policy.enableRules[0].services:
-          policy.enableRules[0].services.append(service)
+        policy.enableRules[0].services.append(service)
     else:
       policy.enableRules.append(
           messages.GoogleApiServiceusageV2betaEnableRule(
@@ -743,9 +1145,74 @@ def AddEnableRule(
     exceptions.ReraiseError(e, exceptions.EnableServiceException)
 
 
+def AddMcpEnableRule(
+    service: str,
+    project: str,
+    folder: str = None,
+    organization: str = None,
+):
+  """Make API call to enable a specific service in mcp policy.
+
+  Args:
+    service: The identifier of the service to enable, for example
+      'serviceusage.googleapis.com'.
+    project: The project for which to enable the service.
+    folder: The folder for which to enable the service.
+    organization: The organization for which to enable the service.
+
+  Raises:
+    exceptions.EnableServiceException: when enabling API fails.
+    apitools_exceptions.HttpError: Another miscellaneous error with the service.
+
+  Returns:
+    The result of the operation
+  """
+  client = _GetClientInstance(version=_V2BETA_VERSION)
+  messages = client.MESSAGES_MODULE
+
+  resource_name = _PROJECT_RESOURCE % project
+
+  if folder:
+    resource_name = _FOLDER_RESOURCE % folder
+
+  if organization:
+    resource_name = _ORGANIZATION_RESOURCE % organization
+
+  policy_name = resource_name + _MCP_POLICY_DEFAULT % 'default'
+
+  try:
+    policy = GetMcpPolicy(policy_name)
+
+    if policy.mcpEnableRules:
+      for mcp_service in policy.mcpEnableRules[0].mcpServices:
+        if mcp_service.service == _SERVICE_RESOURCE % service:
+          raise exceptions.ConfigError(
+              'The service ' + service + ' is already enabled for MCP.'
+          )
+
+      policy.mcpEnableRules[0].mcpServices.append(
+          messages.McpService(service=_SERVICE_RESOURCE % service)
+      )
+    else:
+      policy.mcpEnableRules.append(
+          messages.McpEnableRule(
+              mcpServices=[
+                  messages.McpService(service=_SERVICE_RESOURCE % service)
+              ]
+          )
+      )
+
+    return UpdateMcpPolicy(policy, policy_name)
+  except (
+      apitools_exceptions.HttpForbiddenError,
+      apitools_exceptions.HttpNotFoundError,
+  ) as e:
+    exceptions.ReraiseError(e, exceptions.EnableMcpServiceException)
+
+
 def RemoveEnableRule(
     project: str,
-    service: str,
+    services: List[str],
     consumer_policy_name: str = 'default',
     force: bool = False,
     folder: str = None,
@@ -758,8 +1225,8 @@ def RemoveEnableRule(
 
   Args:
     project: The project for which to disable the service.
-    service: The identifier of the service to disable, for example
-      'serviceusage.googleapis.com'.
+    services: The list of identifiers of the services to disable, for example
+      ['serviceusage.googleapis.com', 'apikeys.googleapis.com'].
     consumer_policy_name: Name of consumer policy. The default name is
       "default".
     force: Disable service with usage within last 30 days or disable recently
@@ -795,22 +1262,31 @@ def RemoveEnableRule(
   try:
     current_policy = GetConsumerPolicyV2Beta(policy_name)
 
-    service_is_enabled = False
+    services_to_remove = {
+        service
+        for service in services
+        if any(
+            _SERVICE_RESOURCE % service in enable_rule.services
+            for enable_rule in current_policy.enableRules
+        )
+    }
 
-    for enable_rule in current_policy.enableRules:
-      if _SERVICE_RESOURCE % service in enable_rule.services:
-        service_is_enabled = True
-        break
+    services = [
+        service for service in services if service not in services_to_remove
+    ]
 
-    if not service_is_enabled:
+    if not services_to_remove:
       raise exceptions.ConfigError(
-          'The service ' + service + ' is not enabled.'
+          'The services '
+          + ','.join(services)
+          + ' are not enabled in the consumer policy.'
       )
 
     proposed_policy = copy.deepcopy(current_policy)
     for enable_rule in proposed_policy.enableRules:
-      if _SERVICE_RESOURCE % service in enable_rule.services:
-        enable_rule.services.remove(_SERVICE_RESOURCE % service)
+      for service in services_to_remove:
+        if _SERVICE_RESOURCE % service in enable_rule.services:
+          enable_rule.services.remove(_SERVICE_RESOURCE % service)
 
     to_remove = []
 
@@ -822,23 +1298,27 @@ def RemoveEnableRule(
 
       analysis_reponse = encoding.MessageToDict(op.response)
 
+      missing_dependency = {}
+
       if 'analysis' in analysis_reponse:
         for analysis in analysis_reponse['analysis']:
           for warning in analysis['analysisResult']['warnings']:
-            ## check if analysis is related to service to be removed.
-            if _SERVICE_RESOURCE % service in warning['detail']:
-              to_remove.append(analysis['service'])
+            for service in services_to_remove:
+              ## check if analysis is related to service to be removed.
+              if _SERVICE_RESOURCE % service == warning['missingDependency']:
+                if service not in missing_dependency:
+                  missing_dependency[service] = []
+                missing_dependency[service].append(analysis['service'])
+                to_remove.append(analysis['service'])
 
       if not disable_dependency_services and to_remove:
-        to_remove = ','.join(to_remove)
+        json_string = json.dumps(missing_dependency)
         raise exceptions.ConfigError(
-            'The service '
-            + service
-            + ' is depended on by the following active service(s) '
-            + to_remove
-            + ' . Provide the --disable-dependency-services flag to disable'
-            ' them, or --bypass-dependency-service-check to ignore this'
-            ' check.'
+            'The services are depended on by the following active service(s) '
+            + json_string
+            + ' . Please remove the active dependent services or provide the'
+            ' --disable-dependency-services flag to disable them, or'
+            ' --bypass-dependency-service-check to ignore this check.'
         )
 
     to_remove = set(to_remove)
@@ -872,6 +1352,74 @@ def RemoveEnableRule(
     exceptions.ReraiseError(e, exceptions.Error)
 
 
+def RemoveMcpEnableRule(
+    project: str,
+    service: str,
+    mcp_policy_name: str = 'default',
+    folder: str = None,
+    organization: str = None,
+):
+  """Make API call to disable a service for MCP.
+
+  Args:
+    project: The project for which to disable the service for MCP.
+    service: The service to disable for MCP, for example
+      'serviceusage.googleapis.com'.
+    mcp_policy_name: Name of MCP policy. The default name is "default".
+    folder: The folder for which to disable the service.
+    organization: The organization for which to disable the service.
+
+  Raises:
+    exceptions.EnableMcpServiceException: when disabling API fails.
+    apitools_exceptions.HttpError: Another miscellaneous error with the service.
+
+  Returns:
+    The result of the operation
+  """
+
+  resource_name = _PROJECT_RESOURCE % project
+
+  if folder:
+    resource_name = _FOLDER_RESOURCE % folder
+
+  if organization:
+    resource_name = _ORGANIZATION_RESOURCE % organization
+
+  policy_name = resource_name + _MCP_POLICY_DEFAULT % mcp_policy_name
+
+  try:
+    policy = GetMcpPolicy(policy_name)
+
+    already_disabled = True
+
+    updated_mcp_policy = copy.deepcopy(policy)
+    updated_mcp_policy.mcpEnableRules.clear()
+
+    if policy.mcpEnableRules:
+      for mcp_enable_rule in policy.mcpEnableRules:
+        rule = copy.deepcopy(mcp_enable_rule)
+        for mcp_service in rule.mcpServices:
+          if mcp_service.service == _SERVICE_RESOURCE % service:
+            already_disabled = False
+            rule.mcpServices.remove(mcp_service)
+        if rule.mcpServices:
+          updated_mcp_policy.mcpEnableRules.append(rule)
+
+    if already_disabled:
+      raise exceptions.ConfigError(
+          'The service ' + service + ' is not enabled for MCP.'
+      )
+
+    return UpdateMcpPolicy(updated_mcp_policy, policy_name)
+  except (
+      apitools_exceptions.HttpForbiddenError,
+      apitools_exceptions.HttpNotFoundError,
+  ) as e:
+    exceptions.ReraiseError(e, exceptions.EnableMcpServiceException)
+  except apitools_exceptions.HttpBadRequestError as e:
+    exceptions.ReraiseError(e, exceptions.Error)
+
+
 def EnableApiCall(project, service):
   """Make API call to enable a specific service.
 
@@ -1066,11 +1614,13 @@ def ListServicesV2Beta(
           services[service_name] = service_state.service.displayName
 
     else:
-      for category_service in ListCategoryServices(
-          resource_name, _GOOGLE_CATEGORY_RESOURCE, page_size, limit
+      for public_service in _ListPublicServices(page_size, limit):
+        services[public_service.name] = public_service.displayName
+      for shared_service in _ListSharedServices(
+          resource_name, page_size, limit
       ):
-        services[category_service.service.name] = (
-            category_service.service.displayName
+        services[shared_service.service.name] = (
+            shared_service.service.displayName
         )
 
     result = []
@@ -1420,6 +1970,77 @@ def _ValidateConsumer(consumer):
   raise exceptions.Error('invalid consumer format "%s".' % consumer)
 
 
+def _ListPublicServices(page_size=1000, limit=sys.maxsize):
+  """Make API call to list public services.
+
+  Args:
+    page_size: The page size to list. default=1000
+    limit: The max number of services to display.
+
+  Raises:
+    exceptions.ListPublicServicesException: when listing public services fails.
+    apitools_exceptions.HttpError: Another miscellaneous error with the service.
+
+  Returns:
+    Message.ListPublicServicesResponse: The public services.
+  """
+  client = _GetClientInstance(version=_V2BETA_VERSION)
+  messages = client.MESSAGES_MODULE
+
+  request = messages.ServiceusageServicesListRequest()
+
+  try:
+    return list_pager.YieldFromList(
+        _Lister(client.services),
+        request,
+        limit=limit,
+        batch_size_attribute='pageSize',
+        batch_size=page_size,
+        field='services',
+    )
+  except (
+      apitools_exceptions.HttpForbiddenError,
+      apitools_exceptions.HttpNotFoundError,
+  ) as e:
+    exceptions.ReraiseError(e, exceptions.ListPublicServicesException)
+
+
+def _ListSharedServices(parent, page_size=1000, limit=sys.maxsize):
+  """Make API call to list shared services.
+
+  Args:
+    parent: The parent for which to list shared services.
+    page_size: The page size to list. default=1000
+    limit: The max number of services to display.
+
+  Raises:
+    exceptions.ListSharedServicesException: when listing shared services fails.
+    apitools_exceptions.HttpError: Another miscellaneous error with the service.
+
+  Returns:
+    Message.ListSharedServicesResponse: The shared services.
+  """
+  client = _GetClientInstance(version=_V2BETA_VERSION)
+  messages = client.MESSAGES_MODULE
+
+  request = messages.ServiceusageSharedServicesListRequest(parent=parent)
+
+  try:
+    return list_pager.YieldFromList(
+        _Lister(client.sharedServices),
+        request,
+        limit=limit,
+        batch_size_attribute='pageSize',
+        batch_size=page_size,
+        field='sharedServices',
+    )
+  except (
+      apitools_exceptions.HttpForbiddenError,
+      apitools_exceptions.HttpNotFoundError,
+  ) as e:
+    exceptions.ReraiseError(e, exceptions.ListSharedServicesException)
+
+
 def _GetClientInstance(version='v1'):
   """Get a client instance for service usage."""
   # pylint:disable=protected-access
