@@ -611,6 +611,14 @@ class RegionsChangeAnnotationChange(NonTemplateConfigChanger):
   to_remove: str
 
   def Adjust(self, resource):
+    final_list = self.GetFinalList(resource)
+    resource.annotations[k8s_object.MULTI_REGION_REGIONS_ANNOTATION] = ','.join(
+        final_list
+    )
+    return resource
+
+  def GetFinalList(self, resource):
+    """Returns the final list of regions after applying the changes."""
     annotation = (
         resource.annotations.get(k8s_object.MULTI_REGION_REGIONS_ANNOTATION)
         or None
@@ -620,10 +628,7 @@ class RegionsChangeAnnotationChange(NonTemplateConfigChanger):
     to_remove = self.to_remove.split(',') if self.to_remove else []
     final_list = [x for x in existing if x not in to_remove]
     final_list.extend([x for x in to_add if x not in existing])
-    resource.annotations[k8s_object.MULTI_REGION_REGIONS_ANNOTATION] = ','.join(
-        final_list
-    )
-    return resource
+    return final_list
 
 
 @dataclasses.dataclass(frozen=True)
@@ -1301,9 +1306,9 @@ class RevisionNameChanges(TemplateConfigChanger):
     return resource
 
 
-def _GenerateVolumeName(prefix):
+def GenerateVolumeName(prefix):
   """Randomly generated name with the given prefix."""
-  return name_generator.GenerateName(sections=3, separator='-', prefix=prefix)
+  return name_generator.GenerateName(sections=2, separator='-', prefix=prefix)
 
 
 def _UniqueVolumeName(source_name, existing_volumes):
@@ -1321,7 +1326,7 @@ def _UniqueVolumeName(source_name, existing_volumes):
   """
   volume_name = None
   while volume_name is None or volume_name in existing_volumes:
-    volume_name = _GenerateVolumeName(source_name)
+    volume_name = GenerateVolumeName(source_name)
   return volume_name
 
 
@@ -1598,24 +1603,6 @@ class NoTrafficChange(NonTemplateConfigChanger):
     return resource
 
 
-# TODO(b/322180968): Once worker specific intance split API/message is ready,
-# switch from service traffic to worker instance split reference.
-class NoPromoteChange(NonTemplateConfigChanger):
-  """Represents the user intent to block instance assignment for a new worker revision."""
-
-  def Adjust(self, resource):
-    """Removes LATEST from the workers instance assignments."""
-    if not resource.generation:
-      raise exceptions.ConfigurationError(
-          '--no-promote not supported when creating a new worker.'
-      )
-
-    resource.spec_traffic.ZeroLatestTraffic(
-        resource.status.latestReadyRevisionName
-    )
-    return resource
-
-
 @dataclasses.dataclass(frozen=True)
 class TrafficChanges(NonTemplateConfigChanger):
   """Represents the user intent to change a service's traffic assignments.
@@ -2272,3 +2259,59 @@ class SetServiceMeshChange(TemplateConfigChanger):
         else f'projects/{self.project}/locations/global/meshes/{self.mesh_name}'
     )
     return resource
+
+
+@dataclasses.dataclass(frozen=True)
+class PresetChange(TemplateConfigChanger):
+  """Sets the preset annotation on the service template.
+
+  Attributes:
+    type: The type of preset to use.
+    config: The config to use for the preset.
+    flatten: Whether to flatten the preset values into the service template.
+  """
+
+  type: str
+  config: Mapping[str, str] = dataclasses.field(default_factory=dict)
+  flatten: bool = True
+
+  def Adjust(self, resource):
+    # TODO(b/412784660): Add support for multiple presets and merge existing
+    # presets.
+    presets = []
+    if service.PRESETS_ANNOTATION in resource.annotations:
+      presets = json.loads(resource.annotations[service.PRESETS_ANNOTATION])
+
+    if presets and presets[0]['type'] != self.type:
+      presets.append({
+          'type': self.type,
+          'config': self.config,
+          'flatten': self.flatten,
+      })
+    else:
+      presets = [{
+          'type': self.type,
+          'config': self.config,
+          'flatten': self.flatten,
+      }]
+    resource.annotations[service.PRESETS_ANNOTATION] = json.dumps(presets)
+    return resource
+
+
+@dataclasses.dataclass(frozen=True)
+class RemovePresetsChange(TemplateConfigChanger):
+  """Removes one or more presets from annotation from the service metadata.
+
+  Attributes:
+    clear_presets: Whether to clear all presets.
+  """
+
+  clear_presets: bool
+
+  def Adjust(self, resource):
+    presets = json.loads(
+        resource.annotations.get(service.PRESETS_ANNOTATION, '[]')
+    )
+    if presets and self.clear_presets:
+      del resource.annotations[service.PRESETS_ANNOTATION]
+      return resource
