@@ -41,6 +41,7 @@ __protobuf__ = proto.module(
         'VertexAISearch',
         'ExternalApi',
         'GoogleSearchRetrieval',
+        'GoogleMaps',
         'EnterpriseWebSearch',
         'DynamicRetrievalConfig',
         'ToolConfig',
@@ -71,7 +72,7 @@ class Tool(proto.Message):
             [FunctionResponse][google.cloud.aiplatform.v1.Part.function_response]
             for each function call in the next turn. Based on the
             function responses, Model will generate the final response
-            back to the user. Maximum 128 function declarations can be
+            back to the user. Maximum 512 function declarations can be
             provided.
         retrieval (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types.Retrieval):
             Optional. Retrieval tool type.
@@ -87,6 +88,9 @@ class Tool(proto.Message):
             Optional. GoogleSearchRetrieval tool type.
             Specialized retrieval tool that is powered by
             Google search.
+        google_maps (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types.GoogleMaps):
+            Optional. GoogleMaps tool type.
+            Tool to support Google Maps in Model.
         enterprise_web_search (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types.EnterpriseWebSearch):
             Optional. Tool to support searching public
             web data, powered by Vertex AI Search and Sec4
@@ -98,19 +102,24 @@ class Tool(proto.Message):
         url_context (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types.UrlContext):
             Optional. Tool to support URL context
             retrieval.
-        computer_use (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types.Tool.ComputerUse):
-            Optional. Tool to support the model
-            interacting directly with the computer. If
-            enabled, it automatically populates computer-use
-            specific Function Declarations.
     """
 
     class GoogleSearch(proto.Message):
         r"""GoogleSearch tool type.
         Tool to support Google Search in Model. Powered by Google.
 
+        Attributes:
+            exclude_domains (MutableSequence[str]):
+                Optional. List of domains to be excluded from the search
+                results. The default limit is 2000 domains. Example:
+                ["amazon.com", "facebook.com"].
         """
 
+        exclude_domains: MutableSequence[str] = proto.RepeatedField(
+            proto.STRING,
+            number=3,
+        )
+
     class CodeExecution(proto.Message):
         r"""Tool that executes code generated by the model, and automatically
         returns the result to the model.
@@ -120,32 +129,6 @@ class Tool(proto.Message):
 
         """
 
-    class ComputerUse(proto.Message):
-        r"""Tool to support computer use.
-
-        Attributes:
-            environment (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types.Tool.ComputerUse.Environment):
-                Required. The environment being operated.
-        """
-        class Environment(proto.Enum):
-            r"""Represents the environment being operated, such as a web
-            browser.
-
-            Values:
-                ENVIRONMENT_UNSPECIFIED (0):
-                    Defaults to browser.
-                ENVIRONMENT_BROWSER (1):
-                    Operates in a web browser.
-            """
-            ENVIRONMENT_UNSPECIFIED = 0
-            ENVIRONMENT_BROWSER = 1
-
-        environment: 'Tool.ComputerUse.Environment' = proto.Field(
-            proto.ENUM,
-            number=1,
-            enum='Tool.ComputerUse.Environment',
-        )
-
     function_declarations: MutableSequence['FunctionDeclaration'] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
@@ -166,6 +149,11 @@ class Tool(proto.Message):
         number=3,
         message='GoogleSearchRetrieval',
     )
+    google_maps: 'GoogleMaps' = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message='GoogleMaps',
+    )
     enterprise_web_search: 'EnterpriseWebSearch' = proto.Field(
         proto.MESSAGE,
         number=6,
@@ -181,11 +169,6 @@ class Tool(proto.Message):
         number=10,
         message='UrlContext',
     )
-    computer_use: ComputerUse = proto.Field(
-        proto.MESSAGE,
-        number=11,
-        message=ComputerUse,
-    )
 
 
 class UrlContext(proto.Message):
@@ -780,12 +763,47 @@ class GoogleSearchRetrieval(proto.Message):
     )
 
 
+class GoogleMaps(proto.Message):
+    r"""Tool to retrieve public maps data for grounding, powered by
+    Google.
+
+    Attributes:
+        api_auth (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types.ApiAuth):
+            The authentication config to access the API. Deprecated.
+            Please use auth_config instead.
+        auth_config (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1.types.AuthConfig):
+            The authentication config to access the API.
+            Only API key is supported.
+    """
+
+    api_auth: gca_api_auth.ApiAuth = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=gca_api_auth.ApiAuth,
+    )
+    auth_config: auth.AuthConfig = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=auth.AuthConfig,
+    )
+
+
 class EnterpriseWebSearch(proto.Message):
     r"""Tool to search public web data, powered by Vertex AI Search
     and Sec4 compliance.
 
+    Attributes:
+        exclude_domains (MutableSequence[str]):
+            Optional. List of domains to be excluded from
+            the search results. The default limit is 2000
+            domains.
     """
 
+    exclude_domains: MutableSequence[str] = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
+
 
 class DynamicRetrievalConfig(proto.Message):
     r"""Describes the options to customize dynamic retrieval.
