@@ -88,6 +88,9 @@ class SubmitBuildRequest(proto.Message):
         release_track (google.api.launch_stage_pb2.LaunchStage):
             Optional. The release track of the client
             that initiated the build request.
+        client (str):
+            Optional. The client that initiated the build
+            request.
     """
 
     class DockerBuild(proto.Message):
@@ -210,6 +213,10 @@ class SubmitBuildRequest(proto.Message):
         number=10,
         enum=launch_stage_pb2.LaunchStage,
     )
+    client: str = proto.Field(
+        proto.STRING,
+        number=11,
+    )
 
 
 class SubmitBuildResponse(proto.Message):
