@@ -1235,7 +1235,7 @@ class UpdateBeta(Update):
     flags.AddCompleteConvertToAutopilotFlag(group)
     flags.AddConvertToStandardFlag(group)
     flags.AddSecretManagerEnableFlagGroup(group, is_update=True)
-    flags.AddSecretSyncFlagGroup(group, hidden=True, is_update=True)
+    flags.AddSecretSyncFlagGroup(group, hidden=False, is_update=True)
     flags.AddEnableCiliumClusterwideNetworkPolicyFlag(group, is_update=True)
     flags.AddEnableKubeletReadonlyPortFlag(group)
     flags.AddAutoprovisioningEnableKubeletReadonlyPortFlag(group)
@@ -1610,7 +1610,7 @@ class UpdateAlpha(Update):
     flags.AddCompleteConvertToAutopilotFlag(group)
     flags.AddConvertToStandardFlag(group)
     flags.AddSecretManagerEnableFlagGroup(group, is_update=True)
-    flags.AddSecretSyncFlagGroup(group, hidden=True, is_update=True)
+    flags.AddSecretSyncFlagGroup(group, hidden=False, is_update=True)
     flags.AddEnableCiliumClusterwideNetworkPolicyFlag(group, is_update=True)
     flags.AddEnableKubeletReadonlyPortFlag(group)
     flags.AddAutoprovisioningEnableKubeletReadonlyPortFlag(group)
