@@ -133,6 +133,7 @@ class Deploy(base.Command):
     flags.AddCpuThrottlingFlag(parser)
     flags.AddCustomAudiencesFlag(parser)
     flags.AddDefaultUrlFlag(parser)
+    flags.AddDeployHealthCheckFlag(parser)
     flags.AddDescriptionFlag(parser)
     flags.AddEgressSettingsFlag(parser)
     flags.AddEncryptionKeyShutdownHoursFlag(parser)
@@ -184,7 +185,9 @@ class Deploy(base.Command):
   def Args(cls, parser):
     cls.CommonArgs(parser)
     container_args = ContainerArgGroup(cls.ReleaseTrack())
-    container_parser.AddContainerFlags(parser, container_args)
+    container_parser.AddContainerFlags(
+        parser, container_args, cls.ReleaseTrack()
+    )
 
   def GetAllowUnauth(self, args, operations, service_ref, service_exists):
     """Returns allow_unauth value for a service change.
@@ -678,6 +681,8 @@ class Deploy(base.Command):
     Args:
       service: existing Cloud run service.
     """
+    if not service:
+      return None
     source_location_map = service.source_deploy_no_build_source_location_map
     logging.debug('source_location map: %s', source_location_map)
     if not source_location_map:
@@ -1193,11 +1198,12 @@ class BetaDeploy(Deploy):
     cls.CommonArgs(parser)
 
     # Flags specific to managed CR
-    flags.AddDeployHealthCheckFlag(parser)
     flags.SERVICE_MESH_FLAG.AddToParser(parser)
     flags.AddIapFlag(parser)
     container_args = ContainerArgGroup(cls.ReleaseTrack())
-    container_parser.AddContainerFlags(parser, container_args)
+    container_parser.AddContainerFlags(
+        parser, container_args, cls.ReleaseTrack()
+    )
 
 
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
@@ -1222,7 +1228,6 @@ class AlphaDeploy(BetaDeploy):
     cls.CommonArgs(parser)
 
     # Flags specific to managed CR
-    flags.AddDeployHealthCheckFlag(parser)
     flags.AddIapFlag(parser)
     flags.AddRuntimeFlag(parser)
     flags.SERVICE_MESH_FLAG.AddToParser(parser)
@@ -1231,9 +1236,13 @@ class AlphaDeploy(BetaDeploy):
     flags.MESH_DATAPLANE_FLAG.AddToParser(parser)
     container_args = ContainerArgGroup(cls.ReleaseTrack())
     container_args.AddArgument(flags.ReadinessProbeFlag())
-    container_parser.AddContainerFlags(parser, container_args)
+    container_parser.AddContainerFlags(
+        parser, container_args, cls.ReleaseTrack()
+    )
     flags.AddDelegateBuildsFlag(parser)
     flags.AddOverflowScalingFlag(parser)
+    flags.AddCpuUtilizationFlag(parser)
+    flags.AddConcurrencyUtilizationFlag(parser)
     flags.AddPresetFlags(parser)
 
 
